@@ -1150,10 +1150,53 @@ PLAN_RESULT_SCHEMA = '''{
         "tracedata": {
             "additionalProperties": false,
             "properties": {
+                "client": {
+                    "maxLength": 256,
+                    "minLength": 2,
+                    "pattern": "\\w+",
+                    "type": "string"
+                },
                 "code": {
                     "maxLength": 256,
                     "minLength": 3,
                     "type": "string"
+                },
+                "method": {
+                    "enum": [
+                        "PLAN",
+                        "CONVERT",
+                        "ANALYTICS",
+                        "PREDICT",
+                        "ACTUALIZE",
+                        "VALIDATE",
+                        "ROUTE",
+                        "MATRIX",
+                        "CLUSTER"
+                    ],
+                    "type": "string"
+                },
+                "server": {
+                    "maxLength": 256,
+                    "minLength": 2,
+                    "type": "string"
+                },
+                "service": {
+                    "enum": [
+                        "LASTMILE",
+                        "DELIVERY",
+                        "FIELDSERVICE",
+                        "MERCHANDISER",
+                        "ROUTING",
+                        "CLUSTERING",
+                        "ACCOUNT",
+                        "STOCK",
+                        "ADMIN"
+                    ],
+                    "type": "string"
+                },
+                "time": {
+                    "format": "date-time",
+                    "type": "string"
                 }
             },
             "required": [
@@ -1332,6 +1375,30 @@ PLAN_RESULT_SCHEMA = '''{
                                             },
                                             "type": "object"
                                         },
+                                        "cargo_features": {
+                                            "default": [],
+                                            "items": {
+                                                "maxLength": 256,
+                                                "minLength": 1,
+                                                "type": "string"
+                                            },
+                                            "maxItems": 1000,
+                                            "minItems": 0,
+                                            "type": "array",
+                                            "uniqueItems": true
+                                        },
+                                        "cargo_restrictions": {
+                                            "default": [],
+                                            "items": {
+                                                "maxLength": 256,
+                                                "minLength": 1,
+                                                "type": "string"
+                                            },
+                                            "maxItems": 1000,
+                                            "minItems": 0,
+                                            "type": "array",
+                                            "uniqueItems": true
+                                        },
                                         "height": {
                                             "default": 0,
                                             "format": "double",
@@ -1445,7 +1512,7 @@ PLAN_RESULT_SCHEMA = '''{
                                         "type": "object"
                                     },
                                     "reward": {
-                                        "default": 1000,
+                                        "default": 1000.1,
                                         "format": "double",
                                         "maximum": 1000000,
                                         "minimum": 0,
